﻿using System;
using System.IO;

namespace PlatformBaseClasses.Stream_Examples
{
  internal class FileStreamExample
  {
    public void RunExample()
    {
      // Create a file called test.txt in the current directory:
      using (Stream fileStream = new FileStream("test.txt", FileMode.Create))
      {
        Console.WriteLine(fileStream.CanRead); // True
        Console.WriteLine(fileStream.CanWrite); // True
        Console.WriteLine(fileStream.CanSeek); // True

        fileStream.WriteByte(101);
        fileStream.WriteByte(102);
        byte[] block = { 1, 2, 3, 4, 5 };
        fileStream.Write(block, 0, block.Length); // Write block of 5 bytes

        Console.WriteLine(fileStream.Length); // 7
        Console.WriteLine(fileStream.Position); // 7

        fileStream.Position = 0; // Move back to the start

        Console.WriteLine(fileStream.ReadByte()); // 101
        Console.WriteLine(fileStream.ReadByte()); // 102

        // Read from the stream back into the block array:
        Console.WriteLine(fileStream.Read(block, 0, block.Length)); // 5

        // Assuming the last Read returned 5, we'll be at
        // the end of the file, so Read will now return 0:
        Console.WriteLine(fileStream.Read(block, 0, block.Length)); // 0
      }
    }

    public async void RunExampleAsync()
    {
      using (Stream s = new FileStream("test.txt", FileMode.Create))
      {
        byte[] block = { 1, 2, 3, 4, 5 };
        await s.WriteAsync(block, 0, block.Length); // Write asychronously
        s.Position = 0; // Move back to the start
        // Read from the stream back into the block array:
        Console.WriteLine(await s.ReadAsync(block, 0, block.Length)); // 5
      }
    }
  }
}